"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KMSMock = void 0;
const typescript_helper_functions_1 = require("typescript-helper-functions");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * KMS Mock class
 */
class KMSMock extends typescript_helper_functions_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks an AWS.KMS.DecryptResponse response
         */
        this.DecryptResponse = {};
        /**
         * Mocks an AWS.KMS.EncryptResponse response
         */
        this.EncryptResponse = {};
    }
    /**
     * Create the KMS mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // decrypt response
            decrypt: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DecryptResponse);
                }),
            },
            // encrypt response
            encrypt: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.EncryptResponse);
                }),
            },
        };
        // create the functions
        let functions = new AWS.KMS();
        functions = {
            decrypt: () => awsResponses.decrypt,
            encrypt: () => awsResponses.encrypt,
        };
        return functions;
    }
}
exports.KMSMock = KMSMock;
//# sourceMappingURL=mock.js.map